@@ -1,4 +1,5 @@
 """Dump chemRxiv data in JSONL format."""
+
 import logging
 import os
 import sys
@@ -28,10 +29,10 @@ def chemrxiv(
     stored in jsonl format in save_path.
 
     Args:
-        begin_date (Optional[str], optional): begin date expressed as YYYY-MM-DD.
-            Defaults to None.
-        end_date (Optional[str], optional): end date expressed as YYYY-MM-DD.
-            Defaults to None.
+        begin_date (str, optional): begin date expressed as YYYY-MM-DD.
+            Defaults to None, i.e., earliest possible.
+        end_date (str, optional): end date expressed as YYYY-MM-DD.
+            Defaults to None, i.e., today.
         save_path (str, optional): Path where the dump is stored.
             Defaults to save_path.
     """
