@@ -3,6 +3,7 @@ import os
 import sys
 from datetime import datetime
 from typing import Dict, Optional
+from urllib.parse import urljoin
 
 import requests
 
@@ -18,7 +19,7 @@ class ChemrxivAPI:
     Adapted from https://github.com/fxcoudert/tools/blob/master/chemRxiv/chemRxiv.py.
     """
 
-    base = "https://chemrxiv.org/engage/chemrxiv/public-api/v1"
+    base = "https://chemrxiv.org/engage/chemrxiv/public-api/v1/"
 
     def __init__(
         self,
@@ -70,17 +71,16 @@ class ChemrxivAPI:
         """Send an API request to open Engage."""
 
         if method.casefold() == "get":
-            return requests.get(url, params=params)
+            return requests.get(url, params=params, timeout=10)
         elif method.casefold() == "post":
-            return requests.post(url, json=params)
+            return requests.post(url, json=params, timeout=10)
         else:
             raise ConnectionError(f"Unknown method for query: {method}")
 
     def query(self, query, method="get", params=None):
         """Perform a direct query."""
-        r = self.request(
-            os.path.join(f"{self.base}", f"{query}"), method, params=params
-        )
+
+        r = self.request(urljoin(self.base, query), method, params=params)
         r.raise_for_status()
         return r.json()
 
@@ -97,7 +97,7 @@ class ChemrxivAPI:
                     "searchDateTo": self.end_date,
                 }
             )
-            r = self.request(os.path.join(self.base, query), method, params=params)
+            r = self.request(urljoin(self.base, query), method, params=params)
             if r.status_code == 400:
                 raise ValueError(r.json()["message"])
             r.raise_for_status()
